@@ -17,10 +17,16 @@ import logging
 tadmap_loglevel = logging.WARNING #WARNING
 
 def set_loglevel(l):
+    """Set the loglevel to one of logging.{ERROR,WARNING,INFO,DEBUG}. Default = WARNING
+"""
+    
     global tadmap_loglevel
     print("Changing loglevel from %s to %s" % (tadmap_loglevel, l))
     tadmap_loglevel = l
-
+    if tadmap_loglevel == logging.DEBUG:
+        global DEBUG_MODE
+        DEBUG_MODE = True
+    
 
 def tadmap_debug(*args, **kwargs):
     if tadmap_loglevel <= logging.DEBUG: print("DEBUG: ", *args, **kwargs)
